@@ -31,6 +31,10 @@ class logpattern:
             "Gurobi (?P<Version>\d{1,2}\.[^\s]+) \((?P<Platform>[^\)]+)\) logging started (?P<Time>.*)$"
         ),
         re.compile("Logging started (?P<Time>.*)$"),
+        re.compile(
+            "Gurobi Compute Server Worker version (?P<Version>\d{1,2}\.[^\s]+) build (.*) \((?P<Platform>[^\)]+)\)$"
+        ),
+        re.compile("Compute Server job ID: (?P<JobID>.*)$")
     ]
 
     # Parameter settings
@@ -110,7 +114,7 @@ class logpattern:
             "Optimize a model with (?P<NumConstrs>\d+) (R|r)ows, (?P<NumVars>\d+) (C|c)olumns and (?P<NumNZs>\d+) (N|n)on(Z|z)ero(e?)s"
         ),
         re.compile("Presolve time: (?P<PresolveTime>[\d\.]+)s"),
-        re.compile("Thread count was (?P<Threads>\d+)"),
+        re.compile("Thread count was (?P<Threads>\d+) \(of (?P<Cores>\d+) available processors\)"),
         re.compile("Distributed MIP job count: (?P<DistributedMIPJobs>\d+)"),
         re.compile("Concurrent MIP job count: (?P<ConcurrentJobs>\d+)"),
         re.compile("Reading time = (?P<ReadTime>[\d\.]+) seconds"),
@@ -343,7 +347,9 @@ def get_log_info(loglines, verbose=False):
         print("Error: Could not find initial log message in logfile")
         return None
     else:
-        values.update(result)
+        # get all header information
+        for _,result in _regex_matches(loglines[:first_line+1], logpattern.headers):
+            values.update(result)
 
     # Discard previous lines
     loglines = loglines[first_line:]
@@ -444,6 +450,41 @@ def get_log_info(loglines, verbose=False):
             if result:
                 values["Cuts: " + result["Name"].strip()] = int(result["Count"])
 
+    # NoRel log
+    norel_log_start = re.compile("Starting NoRel heuristic")
+    norel_first_line, result = _regex_first_match(
+        loglines, [norel_log_start], reverse=False
+    )
+    if norel_first_line and norel_first_line < len(loglines) - 1:
+        norel_last_line = _get_last_nonempty_line(loglines, norel_first_line + 1)
+        norel_primal_regex = re.compile(
+            "Found heuristic solution:\sobjective\s(?P<Incumbent>[^\s]+)"
+        )
+        norel_elapsed_time = re.compile(
+            "Elapsed time for NoRel heuristic:\s(?P<Time>\d+)s"
+        )
+        norel_elapsed_bound = re.compile(
+            "Elapsed time for NoRel heuristic:\s(?P<Time>\d+)s\s\(best\sbound\s(?P<BestBd>[^\s]+)\)"
+        )
+        norel_log = []
+        norel_incumbent = {}
+        for norel_log_line in loglines[
+            norel_first_line + 1 : norel_last_line + 1
+        ]:
+            # NoRel shows the solutions and timings/bounds on different lines, so
+            # when we see a timing line, we store the most recent incumbent there,
+            # instead of recording the primal when the log line is found.
+            result = norel_primal_regex.match(norel_log_line)
+            if result:
+                norel_incumbent = result.groupdict()
+            result = norel_elapsed_bound.match(norel_log_line) or norel_elapsed_time.match(norel_log_line)
+            if result:
+                tmp = result.groupdict()
+                tmp.update(norel_incumbent)
+                norel_log.append(tmp)
+        if len(norel_log) > 0:
+            values["NoRelLog"] = norel_log
+
     # Simplex Log (can be regular LP, root node or crossover)
     simplex_log_start = re.compile(
         "Iteration(\s+)Objective(\s+)Primal Inf.(\s+)Dual Inf.(\s+)Time"
@@ -523,9 +564,6 @@ def get_log_info(loglines, verbose=False):
             float_pattern
         )
     )
-    tree_search_dev_heuristic = re.compile(
-        r"New incumbent \({0}s\): (?P<Heuristic>.*?) heuristic.*".format(float_pattern)
-    )
 
     tree_search_log = []
     ignored_lines = 0
@@ -565,10 +603,6 @@ def get_log_info(loglines, verbose=False):
                 if lastheur and result.get("NewSolution") == "H":
                     result["NewSolution"] = lastheur
                 tree_search_log.append(result)
-            elif tree_search_dev_heuristic.match(tree_search_log_line):
-                lastheur = tree_search_dev_heuristic.match(tree_search_log_line).group(
-                    "Heuristic"
-                )
             else:
                 ignored_lines += 1
 
@@ -731,6 +765,20 @@ def get_dataframe(logfiles, timelines=False, verbose=False, merged_logs=False):
     summary = summary.replace("-", nan)
 
     if timelines:
+
+        # collect norel log
+        norel = pd.DataFrame()
+        for log_info in log_infos:
+            log = log_info.get("LogFilePath")
+            final = summary[summary["LogFilePath"] == log]
+            nrlines = log_info.get("NoRelLog")
+            if nrlines is not None:
+                norel_ = pd.DataFrame(nrlines).apply(
+                    pd.to_numeric, errors="coerce"
+                )
+                _copy_keys(final, norel_)
+                norel = norel.append(norel_, ignore_index=True)
+
         # collect root LP log
         rootlp = pd.DataFrame()
         for log_info in log_infos:
@@ -785,7 +833,7 @@ def get_dataframe(logfiles, timelines=False, verbose=False, merged_logs=False):
 
                 tl = tl.append(tl_, ignore_index=True)
 
-        return summary, tl, rootlp
+        return summary, dict(nodelog=tl, rootlp=rootlp, norel=norel)
     else:
         return summary
 
